Options: R Commander Options

View source: R/file-menu.R

OptionsR Documentation

R Commander Options

Description

R Commander Options

Usage

Options()

Details

This dialog allows you to change the options of the running instance of R Commander.

The current Rcmdr options can be saved via Tools -> Save Rcmdr options... menu. Changes can be made to the .Rprofile file before saving the options.

See Startup for a description of the ‘.Rprofile’ file and the R startup process in general.

See Commander for a description of the various R Commander options.

Author(s)

Manuel Munoz-Marquez


Rcmdr documentation built on Sept. 17, 2026, 1:08 a.m.