| Plugins | R Documentation |
R Commander Plug-in Packages
listPlugins(loaded = FALSE)
loaded |
if |
Plug-ins are R packages that extend the R Command interface.
An R Commander plug-in is an ordinary R package that (1) provides extensions to the R Commander menus is a file named menus.txt located in the package's etc directory; (2) provides call-back functions required by these menus; and (3) in an RcmdrModels: field in the package's DESCRIPTION file, augments the list of model objects recognized by the R Commander.
The menus provided by a plug-in package are merged with the standard Commander menus.
It is also possible to remove menus and menu items from the standard Commander menu file or from the files of plug-ins installed before the current one.
Plug-in packages given in the R Commander plugins option (see Commander) are automatically loaded when the Commander starts up.
Plug-in packages may also be loaded via the Commander Tools -> Load Rcmdr plug-in(s) menu; a restart of the Commander is required to install the new menus. Finally, loading a plug-in package when the Rcmdr is not loaded will load the Rcmdr and activate the plug-in.
An illustrative R Commander plug-in package, RcmdrPlugin.TeachingDemos, is available on CRAN.
A variety of utility functions is available to support R Commander plug-in packages; see Rcmdr.Utilities.
For more details, see Fox, Writing R Commander Plug-in Packages at https://www.john-fox.ca/RCommander/plug-ins.html.
Commander, Rcmdr.Utilities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.