| RcmdrPager | R Documentation |
Pager for Text Files
RcmdrPager(file, header, title, delete.file)
file |
character vector of file(s) to be displayed. |
header |
for the beginning of each file. |
title |
for window. |
delete.file |
delete file(s) on close. |
This is a slightly modified version of the tkpager, changed to use the Rcmdr monospaced font and a white background.
tkpager.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.