RemoveRows: Remove Rows from Active Data Set

View source: R/data-menu.R

RemoveRowsR Documentation

Remove Rows from Active Data Set

Description

Remove Rows from Active Data Set

Details

This menu option can be used to build a new data set by removing rows by name.

In the "Indices or names of row(s) to select" field, enter the names of the rows you wish to keep, separated by spaces. If a row name contains a space, it must be enclosed in single or double quotes. In all other cases, quotes are not required. You can also specify a name for the resulting data set in the "Name for new data set" field. The new data set will automatically become the active data set.

If the data set has no associated row names, the original row indices are used as names. Keep in mind that subsequent operations do not alter these row names; therefore, the numbers will always refer to the original row positions.

This menu option produces a call to the [.data.frame method from the base package.

See Also

See also SelectRows.


Rcmdr documentation built on May 3, 2026, 9:06 a.m.