| dropUnusedFactorLevels | R Documentation |
Drop Unused Factor Levels
Following filtering or recoding procedures, certain factor levels may exhibit zero frequencies. This menu option allows users to remove such unobserved levels from the factor variable.
This menu option calls the droplevles function from the base package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.