linearRegressionModel: Rcmdr Linear Regression Model

linearRegressionModelR Documentation

Rcmdr Linear Regression Model

Description

Rcmdr Linear Regression Model

Details

This menu option can be used to build a linear regression model. This is a linear model in which the response and all explanatory variables are numeric.

After selecting this option, in the new dialog, optionally, change the model name in the first field.

Select a response variable from the left list box, followed by one or more variables as explanatory variables from the right list box.

You may also specify a list of indices/row names to exclude in the third field.

Or a subset of the data by providing a subset expression, in fourth field.

Clicking the OK button produces a call to the lm function in the stats package to build the regression model, followed by a call to summarize and print the results.

See Also

See linearModel for a more detailed description of this menu option.


Rcmdr documentation built on May 3, 2026, 9:06 a.m.