readDataFromPackage: Read data from package

View source: R/data-menu.R

readDataFromPackageR Documentation

Read data from package

Description

Read data from package

Details

This menu option can be used to load data sets provided by currently attached packages.

Selecting the menu items Data -> Data in packages -> Read data set from an attached package... opens a new dialog window.

Double-clicking an item in the left list box displays the available data sets for the selected package in the right list box. Once a data set is selected, clicking OK loads and activates it.

Additionally, documentation for a selected data set can be accessed by clicking the Help on selected data set button.

If the name of the data set is already known, it can be entered directly into the "Enter name of data set:" field. Note that this field is only available before a package has been selected from the list.

For example, double-clicking carData in the left list, selecting Chile in the right list, and clicking OK will load and activate the Chile data set from the carData package.

This menu option calls the data function from the utils-package package.


Rcmdr documentation built on May 3, 2026, 9:06 a.m.