stepwiseRegression: Stepwise Model Selection

stepwiseRegressionR Documentation

Stepwise Model Selection

Description

Stepwise Model Selection

Details

This menu option performs stepwise model selection using either BIC or AIC for active model.

The selection direction determines whether the process starts with the full set of variables and removes them (backward step) or starts with an empty model and adds variables to it (forward step). If "backward/forward" or "forward/backward" is selected, the backward and forward steps are alternated.

The selection criterion can be "BIC" (Bayesian Information Criterion) or "AIC" (Akaike Information Criterion).

Note that stepwise labels the criterion in the output as "AIC" regardless of which criterion is actually employed.

This menu option calls the stepwise function in the RcmdrMisc package.

See Also

See also lm, linearModel.


Rcmdr documentation built on May 3, 2026, 9:06 a.m.