| Options | R Documentation |
R Commander Options
Options()
This dialog allows you to change the options of the running instance of R Commander.
The current Rcmdr options can be saved via Tools -> Save Rcmdr options... menu.
Changes can be made to the .Rprofile file before saving the options.
See Startup for a description of the ‘.Rprofile’ file and the R startup process in general.
See Commander for a description of the various R Commander options.
Manuel Munoz-Marquez
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.